@@ -13,15 +13,35 @@ from .exceptions import raises
 
 
 class SymmetricKey(BaseSymmetricKey):
+    """Provides symmetric encryption with auto padding.
+
+    Attributes
+    ----------
+    algorthm : str
+        Name of encryption algorithm.
+    padding : str
+        Name of padding standart.
+    key_sizes : iterable
+        Available sizes (in bits) for key.
+    block_size : int
+        Encryption block size in bits.
+    """
     algorithm = "AES-CBC"
     padding = "PKCS7"
     key_sizes = (128, 192, 256)
     block_size = 128
 
+    @raises(exceptions.KeyLoadingError)
     def __init__(self, key: bytes, iv: bytes) -> None:
+        """
+        Parameters
+        ----------
+        key : bytes
+        iv : bytes
+        """
         if (len(key)*8 not in self.key_sizes or
                 len(iv)*8 != self.block_size):
-            raise exceptions.KeyGenerationError(
+            raise exceptions.KeyLoadingError(
                 f"Invalid key/iv size for {self.algorithm} algorithm. "
                 f"Should be one of {self.key_sizes}.")
         self._key = key
@@ -56,6 +76,10 @@ class SymmetricKey(BaseSymmetricKey):
         Returns
         -------
         Symmetric Key object.
+
+        Raises
+        ------
+        KeyGenerationError
         """
         key = os.urandom(key_size // 8)
         iv = os.urandom(cls.block_size // 8)
@@ -73,6 +97,10 @@ class SymmetricKey(BaseSymmetricKey):
         Returns
         -------
         Encrypted bytes.
+
+        Raises
+        ------
+        EncryptionError
         """
         padder = PKCS7(self.block_size).padder()
         encryptor = self._cipher.encryptor()
@@ -91,6 +119,10 @@ class SymmetricKey(BaseSymmetricKey):
         Returns
         -------
         Decrypted bytes.
+
+        Raises
+        ------
+        DecryptionError
         """
         unpadder = PKCS7(self.block_size).unpadder()
         decryptor = self._cipher.decryptor()
